<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>AlertDialog</name>
    <message>
        <source>Alert Dialog</source>
        <translation>İkaz İletişim Kutusu</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>AuthenticationDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Kimlik doğrulama gerekiyor</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Kullanıcı adı:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Parola:</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="vanished">İ&amp;ptal</translation>
    </message>
    <message>
        <source>&amp;Log In</source>
        <translation type="vanished">&amp;Oturum Aç</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Log In</source>
        <translation>Oturum Aç</translation>
    </message>
</context>
<context>
    <name>ConfirmDialog</name>
    <message>
        <source>Alert Dialog</source>
        <translation type="vanished">İkaz İletişim Kutusu</translation>
    </message>
    <message>
        <source>Confirm Dialog</source>
        <translation>Onay İletişim Kutusu</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>DownloadInterruptReason</name>
    <message>
        <source>Unknown reason or not interrupted</source>
        <translation>Bilinmeyen neden veya yarıda kesilmedi</translation>
    </message>
    <message>
        <source>General file operation failure</source>
        <translation>Genel dosya işlemi hatası</translation>
    </message>
    <message>
        <source>The file cannot be written locally, due to access restrictions</source>
        <translation>Erişim kısıtlamalarından dolayı dosyaya yerel olarak yazılamıyor</translation>
    </message>
    <message>
        <source>Insufficient space on the target drive</source>
        <translation>Hedef sürücüde yetersiz alan</translation>
    </message>
    <message>
        <source>The directory or file name is too long</source>
        <translation>Dosya veya dizin adı pek uzun</translation>
    </message>
    <message>
        <source>The file size exceeds the file system limitation</source>
        <translation>Dosya boyutu, dosya sistemi sınırlamasını aşıyor</translation>
    </message>
    <message>
        <source>The file is infected with a virus</source>
        <translation>Dosyada virüs var</translation>
    </message>
    <message>
        <source>Temporary problem (for example file in use, or too many open files)</source>
        <translation>Geçici sorun (örneğin, dosya kullanımda veya çok fazla açık dosya var)</translation>
    </message>
    <message>
        <source>The file was blocked due to local policy</source>
        <translation>Dosya yerel politikadan dolayı engellendi</translation>
    </message>
    <message>
        <source>Checking the safety of the download failed due to unexpected reasons</source>
        <translation>İndirmenin güvenliğini denetleme bilinmeyen nedenlerden dolayı başarısız oldu</translation>
    </message>
    <message>
        <source>File seek past the end of a file (resuming previously interrupted download)</source>
        <translation>Dosya sonundan ötesine bakma girişimi (daha önceden yarıda kesilen indirme sürdürülüyor)</translation>
    </message>
    <message>
        <source>The partial file did not match the expected hash</source>
        <translation>Kısımsal dosya beklenen sağlamayla eşleşmedi</translation>
    </message>
    <message>
        <source>General network failure</source>
        <translation>Genel ağ hatası</translation>
    </message>
    <message>
        <source>The network operation has timed out</source>
        <translation>Ağ işlemi zaman aşımına uğradı</translation>
    </message>
    <message>
        <source>The network connection has been terminated</source>
        <translation>Ağ bağlantısı sonlandırıldı</translation>
    </message>
    <message>
        <source>The server has gone down</source>
        <translation>Sunucu kapandı</translation>
    </message>
    <message>
        <source>The network request was invalid (for example, the URL or scheme is invalid)</source>
        <translation>Ağ isteği geçersizdi (örneğin, URL veya şema geçersiz)</translation>
    </message>
    <message>
        <source>General server failure</source>
        <translation>Genel sunucu hatası</translation>
    </message>
    <message>
        <source>The server does not have the requested data</source>
        <translation>İstenen veri sunucuda yok</translation>
    </message>
    <message>
        <source>The server did not authorize access to the resource</source>
        <translation>Sunucu, özkaynağa erişimi yetkilendirmedi</translation>
    </message>
    <message>
        <source>A problem with the server certificate occurred</source>
        <translation>Sunucu sertifikasıyla ilgili bir sorun oluştu</translation>
    </message>
    <message>
        <source>Access forbidden by the server</source>
        <translation>Erişim, sunucu tarafından engellendi</translation>
    </message>
    <message>
        <source>Unexpected server response</source>
        <translation>Beklenmedik sunucu yanıtı</translation>
    </message>
    <message>
        <source>Download canceled by the user</source>
        <translation>İndirme, kullanıcı tarafından iptal edildi</translation>
    </message>
</context>
<context>
    <name>PromptDialog</name>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Prompt Dialog</source>
        <translation>İstem İletişim Kutusu</translation>
    </message>
</context>
<context>
    <name>QQuickPdfDocument</name>
    <message>
        <source>Cannot open: %1</source>
        <translation>Açılamıyor: %1</translation>
    </message>
    <message>
        <source>no error</source>
        <translation>Hata yok</translation>
    </message>
    <message>
        <source>data not yet available</source>
        <translation>Veri henüz kullanılabilir değil</translation>
    </message>
    <message>
        <source>file not found</source>
        <translation>Dosya bulunamadı</translation>
    </message>
    <message>
        <source>invalid file format</source>
        <translation>Geçersiz dosya biçimi</translation>
    </message>
    <message>
        <source>incorrect password</source>
        <translation>Yanlış parola</translation>
    </message>
    <message>
        <source>unsupported security scheme</source>
        <translation>Desteklenmeyen güvenlik şeması</translation>
    </message>
    <message>
        <source>unknown error</source>
        <translation>Bilinmeyen hata</translation>
    </message>
</context>
<context>
    <name>QQuickWebEngineView</name>
    <message>
        <source>Stop</source>
        <translation type="vanished">Durdur</translation>
    </message>
    <message>
        <source>Reload and Bypass Cache</source>
        <translation type="vanished">Yeniden Yükle ve Önbelleği Atla</translation>
    </message>
    <message>
        <source>Open link in this window</source>
        <translation type="vanished">Bağlantıyı Bu Pencerede Aç</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation type="vanished">Oynat/Çal–Duraklat</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation type="vanished">Sesi Kapat–Aç</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation type="vanished">Sayfayı Kapat</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation type="vanished">Seçimi Kaldır</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation type="vanished">&amp;Kalın</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation type="vanished">&amp;Yatık</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation type="vanished">&amp;Altı Çizili</translation>
    </message>
    <message>
        <source>&amp;Strikethrough</source>
        <translation type="vanished">Üz&amp;eri Çizili</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation type="vanished">&amp;Sola Hizala</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation type="vanished">&amp;Ortaya Hizala</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation type="vanished">Sağa &amp;Hizala</translation>
    </message>
    <message>
        <source>Align &amp;Justified</source>
        <translation type="vanished">İk&amp;i Yana Yasla</translation>
    </message>
    <message>
        <source>&amp;Indent</source>
        <translation type="vanished">&amp;Girintilendir</translation>
    </message>
    <message>
        <source>&amp;Outdent</source>
        <translation type="vanished">Giri&amp;ntiyi Azalt</translation>
    </message>
    <message>
        <source>Insert &amp;Ordered List</source>
        <translation type="vanished">Sı&amp;ralı Liste Ekle</translation>
    </message>
    <message>
        <source>Insert &amp;Unordered List</source>
        <translation type="vanished">Sırası&amp;z Liste Ekle</translation>
    </message>
</context>
<context>
    <name>QWebEnginePage</name>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Reload and Bypass Cache</source>
        <translation>Yeniden Yükle ve Önbelleği Atla</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Oynat/Çal–Duraklat</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Sesi Kapat–Aç</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Sayfayı Kapat</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Seçimi Kaldır</translation>
    </message>
    <message>
        <source>Open link in this window</source>
        <translation>Bağlantıyı Bu Pencerede Aç</translation>
    </message>
    <message>
        <source>Open link in new background tab</source>
        <translation>Bağlantıyı Yeni Arka Plan Sekmesinde Aç</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Kalın</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Yatık</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Altı Çizili</translation>
    </message>
    <message>
        <source>&amp;Strikethrough</source>
        <translation>Üz&amp;eri Çizili</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>&amp;Sola Hizala</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>&amp;Ortaya Hizala</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Sağa &amp;Hizala</translation>
    </message>
    <message>
        <source>Align &amp;Justified</source>
        <translation>İk&amp;i Yana Yasla</translation>
    </message>
    <message>
        <source>&amp;Indent</source>
        <translation>&amp;Girintilendir</translation>
    </message>
    <message>
        <source>&amp;Outdent</source>
        <translation>Giri&amp;ntiyi Azalt</translation>
    </message>
    <message>
        <source>Insert &amp;Ordered List</source>
        <translation>Sı&amp;ralı Liste Ekle</translation>
    </message>
    <message>
        <source>Insert &amp;Unordered List</source>
        <translation>Sırası&amp;z Liste Ekle</translation>
    </message>
    <message>
        <source>Change text direction left to right</source>
        <translation>Metin yönünü soldan sağa olarak değiştir</translation>
    </message>
    <message>
        <source>Change text direction right to left</source>
        <translation>Metin yönünü sağdan sola olarak değiştir</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page? Changes that you made may not be saved.</source>
        <translation>Bu sayfadan ayrılmak istediğinizden emin misiniz? Yaptığınız değişiklikler kaydedilmemiş olabilir.</translation>
    </message>
    <message>
        <source>Select folder to upload</source>
        <translation type="vanished">Yüklenecek Klasör Seç</translation>
    </message>
</context>
<context>
    <name>QtWebEnginePlugin</name>
    <message>
        <source>Cannot create separate instance of WebEngineNewViewRequest</source>
        <translation type="vanished">WebEngineNewViewRequest’in ayrı bir örneği oluşturulamıyor.</translation>
    </message>
    <message>
        <source>Cannot create separate instance of %1</source>
        <translation type="vanished">%1 ögesinin ayrı bir örneği oluşturulamıyor.</translation>
    </message>
</context>
<context>
    <name>QtWebEngineTestSupportPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineErrorPage</source>
        <translation type="vanished">WebEngineErrorPage’in ayrı bir örneği oluşturulamıyor.</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineTestEvent</source>
        <translation type="vanished">WebEngineTestEvent’in ayrı bir örneği oluşturulamıyor.</translation>
    </message>
</context>
<context>
    <name>RenderViewContextMenuQt</name>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>İleri</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Yeniden Yükle</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Kes</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Yapıştır</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Geri Al</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Yinele</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Tümünü Seç</translation>
    </message>
    <message>
        <source>Paste and match style</source>
        <translation>Yapıştır ve Biçemi Eşleştir</translation>
    </message>
    <message>
        <source>Open link in new window</source>
        <translation>Bağlantıyı Yeni Pencerede Aç</translation>
    </message>
    <message>
        <source>Open link in new tab</source>
        <translation>Bağlantıyı Yeni Sekmede Aç</translation>
    </message>
    <message>
        <source>Copy link address</source>
        <translation>Bağlantı Adresini Kopyala</translation>
    </message>
    <message>
        <source>Save link</source>
        <translation>Bağlantıyı Kaydet</translation>
    </message>
    <message>
        <source>Copy image</source>
        <translation>Görseli Kopyala</translation>
    </message>
    <message>
        <source>Copy image address</source>
        <translation>Görsel Adresini Kopyala</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Görseli Kaydet</translation>
    </message>
    <message>
        <source>Copy media address</source>
        <translation>Ortam Adresini Kopyala</translation>
    </message>
    <message>
        <source>Show controls</source>
        <translation>Denetimleri Göster</translation>
    </message>
    <message>
        <source>Loop</source>
        <translation>Döngüle</translation>
    </message>
    <message>
        <source>Save media</source>
        <translation>Ortamı Kaydet</translation>
    </message>
    <message>
        <source>Inspect</source>
        <translation>Denetle</translation>
    </message>
    <message>
        <source>Exit full screen</source>
        <translation>Tam Ekrandan Çık</translation>
    </message>
    <message>
        <source>Save page</source>
        <translation>Sayfayı Kaydet</translation>
    </message>
    <message>
        <source>View page source</source>
        <translation>Sayfa Kaynağını Görüntüle</translation>
    </message>
</context>
<context>
    <name>UIDelegatesManager</name>
    <message>
        <source>Javascript Alert - %1</source>
        <translation>JavaScript İkazı — %1</translation>
    </message>
    <message>
        <source>Javascript Confirm - %1</source>
        <translation>JavaScript Onayı — %1</translation>
    </message>
    <message>
        <source>Javascript Prompt - %1</source>
        <translation>JavaScript İstemi — %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Bu sayfadan ayrılmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>Changes that you made may not be saved.</source>
        <translation>Yaptığınız değişiklikler kaydedilmemiş olabilir.</translation>
    </message>
    <message>
        <source>Connect to proxy &quot;%1&quot; using:</source>
        <translation>“%1” vekiline şunu kullanarak bağlan:</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2://%3</source>
        <translation>%2://%3 konumundaki “%1” için kullanıcı adını ve parolayı girin</translation>
    </message>
</context>
<context>
    <name>WebContentsAdapter</name>
    <message>
        <source>HTTP-POST data can only be sent over HTTP(S) protocol</source>
        <translation>HTTP-POST verisi yalnızca HTTP(S) protokolü üzerinden gönderilebilir</translation>
    </message>
</context>
<context>
    <name>PdfLinkDelegate</name>
    <message>
        <source>Page %1 location %2, %3 zoom %4</source>
        <translation>Sayfa %1, konum %2, %3 yakınlaştırma %4</translation>
    </message>
</context>
<context>
    <name>ColorDialog</name>
    <message>
        <source>Color Picker Dialog</source>
        <translation>Renk Seçicisi İletişim Kutusu</translation>
    </message>
    <message>
        <source>Copy color</source>
        <translation>Rengi Kopyala</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Yapıştır</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>FilePickerController</name>
    <message>
        <source>Accepted types (%1)</source>
        <translation>Kabul edilen türler (%1)</translation>
    </message>
</context>
<context>
    <name>QPdfLinkModel</name>
    <message>
        <source>Page %1 location %2, %3 zoom %4</source>
        <translation>Sayfa %1, konum %2, %3 yakınlaştırma %4</translation>
    </message>
</context>
<context>
    <name>QWebEngineView</name>
    <message>
        <source>Select folder to upload</source>
        <translation>Yüklenecek Klasör Seç</translation>
    </message>
</context>
<context>
    <name>QtWebEngineWidgetUI::TouchSelectionMenuWidget</name>
    <message>
        <source>Cut</source>
        <translation>Kes</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Yapıştır</translation>
    </message>
    <message>
        <source>...</source>
        <translation>…</translation>
    </message>
</context>
</TS>
